@@ -5,6 +5,8 @@ from pydantic import BaseModel
 
 
 class WidgetType(str, Enum):
+    """Widget type"""
+
     Input = "Input"
     InputNumber = "InputNumber"
     TextArea = "TextArea"
@@ -23,6 +25,8 @@ class WidgetType(str, Enum):
 
 
 class ModelPermission(str, Enum):
+    """Model permission"""
+
     Add = "Add"
     Change = "Change"
     Delete = "Delete"
@@ -30,28 +34,41 @@ class ModelPermission(str, Enum):
 
 
 class ListConfigurationFieldSchema(BaseModel):
+    """List configuration field schema"""
+
+    index: int | None
+
     sorter: bool | None
     width: int | None
     is_link: bool | None
     empty_value_display: str
     filter_widget_type: WidgetType | None
     filter_widget_props: dict | None
-    filter_condition: str | None
 
 
 class AddConfigurationFieldSchema(BaseModel):
+    """Add configuration field schema"""
+
+    index: int | None
+
     form_widget_type: WidgetType
     form_widget_props: dict | None
     required: bool | None
 
 
 class ChangeConfigurationFieldSchema(BaseModel):
+    """Change configuration field schema"""
+
+    index: int | None
+
     form_widget_type: WidgetType
     form_widget_props: dict | None
     required: bool | None
 
 
 class ModelFieldSchema(BaseModel):
+    """Model field schema"""
+
     name: str
     list_configuration: ListConfigurationFieldSchema | None
     add_configuration: AddConfigurationFieldSchema | None
@@ -59,6 +76,8 @@ class ModelFieldSchema(BaseModel):
 
 
 class ModelSchema(BaseModel):
+    """Model schema"""
+
     name: str
     permissions: Sequence[ModelPermission]
     fields: Sequence[ModelFieldSchema]
@@ -75,6 +94,8 @@ class ModelSchema(BaseModel):
 
 
 class ConfigurationSchema(BaseModel):
+    """Configuration schema"""
+
     site_name: str
     site_sign_in_logo: str
     site_header_logo: str
@@ -82,3 +103,5 @@ class ConfigurationSchema(BaseModel):
     primary_color: str
     username_field: str
     models: Sequence[ModelSchema]
+    date_format: str
+    datetime_format: str
